--[[
Author - Saudorun
Date - 11/11/2006
Addon - ClassChannel
Version - 1
Purpose - Allow the users to send messages only to other of their same class.
Auto detect Raid/Party/BG.  When not grouped will default to Guild channel.
Provides an override to send messages to guild class members only.

Slash Commands
/cc sends message to class channel autodetected but default to guild if solo.
/cg overrides autoselect and sends to guild.

CC_LIGHTGREEN = 0.5,1.0,0.5;
CC_WHITE = 1.0,1.0,1.0;
CC_TOMATOE = 1,0.5,0.5;
CC_CYAN = 0.0,1.0,1.0;
]]--
--defaults
cc_r=0.0;
cc_g=1.0;
cc_b=1.0;
cg_r=0.4;
cg_g=0.8;
cg_b=0.4;

local cc_message=nil;
local cc_self=nil;
local cc_mode=nil;
local cc_class=nil;
local cc_prefix=nil;
local cc_sender=nil;
local cc_display=nil;


-- this variable is to get the debug output messages printed in the ui. Not intended for use by the user
local cc_debug=0;
-- debug settings ended

function ClassChannel_OnLoad()
	SlashCmdList["CC_COMMAND"] = ClassChannel_SlashCCHandler;
	SLASH_CC_COMMAND1 = "/cc";
	SlashCmdList["CG_COMMAND"] = ClassChannel_SlashCGHandler;
	SLASH_CG_COMMAND1 = "/cg";
		
	this:RegisterEvent("VARIABLES_LOADED");
	this:RegisterEvent("CHAT_MSG_ADDON");
	this:RegisterEvent("PLAYER_ENTERING_WORLD");
	
end

function ClassChannel_OnEvent(event)
	if (event == "VARIABLES_LOADED") then
		if( DEFAULT_CHAT_FRAME ) then
			DEFAULT_CHAT_FRAME:AddMessage("ClassChannel: " .. CC_VER);
		end	 
	elseif (event == "PLAYER_ENTERING_WORLD") then
		cc_class = UnitClass("player");
	elseif (event == "CHAT_MSG_ADDON") then
	    cc_prefix=arg1;
	    cc_message=arg2;
	    cc_mode=arg3;
	    cc_sender=arg4;
	    cc_display="["..cc_class.."]["..cc_sender.."] "..cc_message;
		-- checks for message from the addon and posts it to chat frame
		if (cc_prefix==cc_class) then
			if ((cc_mode == CC_RAID) or (cc_mode == CC_PARTY)) then
				DEFAULT_CHAT_FRAME:AddMessage(cc_display,cc_r,cc_g,cc_b);
			elseif (cc_mode == CC_GUILD) then
				DEFAULT_CHAT_FRAME:AddMessage(cc_display,cg_r,cg_g,cg_b);
			end
		end
	end
end


function ClassChannel_SlashCCHandler(msg)
	if (msg == "") then
		DEFAULT_CHAT_FRAME:AddMessage(CC_CHAT_HELP,1.0,1.0,1.0);
	elseif (msg == "color") then
		ColorPickerFrame.func = ClassChannel_CCColor;
		ColorPickerFrame.cancelFunc = ClassChannel_CCCancelColor;
		ColorPickerFrame:SetColorRGB(cc_r,cc_g,cc_b);
		ColorPickerFrame:Show();		
	else
		cc_mode = CC_NOMODE;
		if (UnitInRaid("player")) then
			cc_mode = CC_RAID;
		elseif (GetNumPartyMembers()>0) then
			cc_mode = CC_PARTY;
		elseif (IsInGuild()) then
			cc_mode = CC_GUILD;
		end
		if (cc_mode ~= CC_NOMODE) then
			SendAddonMessage(cc_class,msg,cc_mode);
		end	
	end
end

function ClassChannel_SlashCGHandler(msg)
	if (msg == "") then
		DEFAULT_CHAT_FRAME:AddMessage(CC_CHAT_HELP,1.0,1.0,1.0);
	elseif (msg == "color") then
		ColorPickerFrame.func = ClassChannel_CGColor;
		ColorPickerFrame.cancelFunc = ClassChannel_CGCancelColor;
		ColorPickerFrame:SetColorRGB(cg_r,cg_g,cg_b);
		ColorPickerFrame:Show();
	else
	cc_mode = CC_NOMODE;
		if (IsInGuild()) then
			cc_mode = CC_GUILD;
		end
		if (cc_mode ~= CC_NOMODE) then
			SendAddonMessage(cc_class,msg,cc_mode);
		end			
	end
end

function ClassChannel_CCColor()
	cc_r,cc_g,cc_b = ColorPickerFrame:GetColorRGB();
end

function ClassChannel_CGColor()
	cg_r,cg_g,cg_b = ColorPickerFrame:GetColorRGB();
end

function ClassChannel_CCCancelColor(prevals)
	cc_r,cc_g,cc_b = unpack(prevals);
end

function ClassChannel_CGCancelColor(prevals)
	cc_r,cc_g,cc_b = unpack(prevals);
end